@@ -6,14 +6,14 @@ use FFI::Platypus;
 use base qw( Exporter );
 
 # ABSTRACT: Memory functions for FFI
-our $VERSION = '0.94'; # VERSION
+our $VERSION = '0.98'; # VERSION
 
 
 our @EXPORT = qw( malloc free calloc realloc memcpy memset strdup strndup );
 
 my $ffi = FFI::Platypus->new( api => 1, experimental => 1);
 $ffi->lib(undef);
-$ffi->package;
+$ffi->bundle;
 sub _ffi { $ffi }
 
 $ffi->attach(malloc  => ['size_t']                     => 'opaque' => '$');
@@ -29,7 +29,7 @@ sub _strdup_impl { $_strdup_impl }
 eval {
   die "do not use c impl" if ($ENV{FFI_PLATYPUS_MEMORY_STRDUP_IMPL}||'libc') eq 'ffi';
   $ffi->attach(strdup  => ['string'] => 'opaque' => '$');
-  $_strdup_impl = 'libc';  
+  $_strdup_impl = 'libc';
 };
 if($@)
 {
@@ -43,7 +43,7 @@ sub _strndup_impl { $_strndup_impl }
 eval {
   die "do not use c impl" if ($ENV{FFI_PLATYPUS_MEMORY_STRDUP_IMPL}||'libc') eq 'ffi';
   $ffi->attach(strndup  => ['string','size_t'] => 'opaque' => '$$');
-  $_strndup_impl = 'libc';  
+  $_strndup_impl = 'libc';
 };
 if($@)
 {
@@ -65,7 +65,7 @@ FFI::Platypus::Memory - Memory functions for FFI
 
 =head1 VERSION
 
-version 0.94
+version 0.98
 
 =head1 SYNOPSIS
 
@@ -77,14 +77,14 @@ version 0.94
  
  # use that memory wisely
  ...
-
+ 
  # free the memory when you are done.
  free $pointer;
 
 =head1 DESCRIPTION
 
-This module provides an interface to common memory functions provided by 
-the standard C library.  They may be useful when constructing interfaces 
+This module provides an interface to common memory functions provided by
+the standard C library.  They may be useful when constructing interfaces
 to C libraries with FFI.  It works mostly with the C<opaque> type and it
 is worth reviewing the section on opaque pointers in L<FFI::Platypus::Type>.
 
@@ -94,16 +94,16 @@ is worth reviewing the section on opaque pointers in L<FFI::Platypus::Type>.
 
  my $pointer = calloc $count, $size;
 
-The C<calloc> function contiguously allocates enough space for I<$count> 
+The C<calloc> function contiguously allocates enough space for I<$count>
 objects that are I<$size> bytes of memory each.
 
 =head2 free
 
  free $pointer;
 
-The C<free> function frees the memory allocated by C<malloc>, C<calloc>, 
-C<realloc> or C<strdup>.  It is important to only free memory that you 
-yourself have allocated.  A good way to crash your program is to try and 
+The C<free> function frees the memory allocated by C<malloc>, C<calloc>,
+C<realloc> or C<strdup>.  It is important to only free memory that you
+yourself have allocated.  A good way to crash your program is to try and
 free a pointer that some C library has returned to you.
 
 =head2 malloc
@@ -116,7 +116,7 @@ The C<malloc> function allocates I<$size> bytes of memory.
 
  memcpy $dst_pointer, $src_pointer, $size;
 
-The C<memcpy> function copies I<$size> bytes from I<$src_pointer> to 
+The C<memcpy> function copies I<$size> bytes from I<$src_pointer> to
 I<$dst_pointer>.  It also returns I<$dst_pointer>.
 
 =head2 memset
@@ -130,10 +130,10 @@ specified by I<$buffer>.
 
  my $new_pointer = realloc $old_pointer, $size;
 
-The C<realloc> function reallocates enough memory to fit I<$size> bytes. 
+The C<realloc> function reallocates enough memory to fit I<$size> bytes.
 It copies the existing data and frees I<$old_pointer>.
 
-If you pass C<undef> in as I<$old_pointer>, then it behaves exactly like 
+If you pass C<undef> in as I<$old_pointer>, then it behaves exactly like
 C<malloc>:
 
  my $pointer = realloc undef, 64; # same as malloc 64
@@ -142,10 +142,10 @@ C<malloc>:
 
  my $pointer = strdup $string;
 
-The C<strdup> function allocates enough memory to contain I<$string> and 
-then copies it to that newly allocated memory.  This version of 
-C<strdup> returns an opaque pointer type, not a string type.  This may 
-seem a little strange, but returning a string type would not be very 
+The C<strdup> function allocates enough memory to contain I<$string> and
+then copies it to that newly allocated memory.  This version of
+C<strdup> returns an opaque pointer type, not a string type.  This may
+seem a little strange, but returning a string type would not be very
 useful in Perl.
 
 =head2 strndup
@@ -195,6 +195,10 @@ Petr Pisar (ppisar)
 
 Mohammad S Anwar (MANWAR)
 
+Håkon Hægland (hakonhagland, HAKONH)
+
+Meredith (merrilymeredith, MHOWARD)
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2015,2016,2017,2018,2019 by Graham Ollis.
